package com.ygtx.gxt.mapper;

import java.util.List;
import com.ygtx.gxt.domain.GxtWorkOrder;
import org.apache.ibatis.annotations.Mapper;

/**
 * 维保工单Mapper接口
 *
 * @author ygtx
 * @date 2025-10-25
 */
@Mapper
public interface GxtWorkOrderMapper
{
    /**
     * 查询维保工单
     *
     * @param id 维保工单主键
     * @return 维保工单
     */
    public GxtWorkOrder selectGxtWorkOrderById(Long id);

    /**
     * 查询维保工单列表
     *
     * @param gxtWorkOrder 维保工单
     * @return 维保工单集合
     */
    public List<GxtWorkOrder> selectGxtWorkOrderList(GxtWorkOrder gxtWorkOrder);

    /**
     * 新增维保工单
     *
     * @param gxtWorkOrder 维保工单
     * @return 结果
     */
    public int insertGxtWorkOrder(GxtWorkOrder gxtWorkOrder);

    /**
     * 修改维保工单
     *
     * @param gxtWorkOrder 维保工单
     * @return 结果
     */
    public int updateGxtWorkOrder(GxtWorkOrder gxtWorkOrder);

    /**
     * 删除维保工单
     *
     * @param id 维保工单主键
     * @return 结果
     */
    public int deleteGxtWorkOrderById(Long id);

    /**
     * 批量删除维保工单
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteGxtWorkOrderByIds(Long[] ids);

    /**
     * 根据工单编码查询维保工单
     *
     * @param orderCode 工单编码
     * @return 维保工单
     */
    public GxtWorkOrder selectGxtWorkOrderByCode(String orderCode);
}
